@@ -15,12 +15,12 @@
  */
 package net.sf.cglib.transform;
 
+import net.sf.cglib.core.Constants;
 import org.objectweb.asm.ClassVisitor;
-import org.objectweb.asm.Opcodes;
 
 abstract public class AbstractClassTransformer extends ClassTransformer {
     protected AbstractClassTransformer() {
-        super(Opcodes.ASM6);
+        super(Constants.ASM_API);
     }
 
     public void setTarget(ClassVisitor target) {
